import * as momentjs from 'moment';
import * as moment_ from 'moment-hijri';
import { Injectable, Component, ViewEncapsulation, Input, Output, EventEmitter, NgModule, defineInjectable } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { NgbDateParserFormatter, NgbDate, NgbDatepickerI18n, NgbCalendar, NgbCalendarIslamicUmalqura, NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { DatePipe, CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/hijri-gregorian-datepicker/consts.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DateType {
}
DateType.Hijri = 1;
DateType.Gregorian = 2;

/**
 * @fileoverview added by tsickle
 * Generated from: lib/hijri-gregorian-datepicker/date-formatter.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment = momentjs;
/** @type {?} */
const momentHijri = moment_;
class DateFormatterService {
    /**
     * @param {?} parserFormatter
     */
    constructor(parserFormatter) {
        this.parserFormatter = parserFormatter;
    }
    /**
     * @param {?} date
     * @return {?}
     */
    ToString(date) {
        /** @type {?} */
        const dateStr = this.parserFormatter.format(date);
        return dateStr;
    }
    /**
     * @param {?} hijriDate
     * @param {?} format
     * @return {?}
     */
    ToHijriDateStruct(hijriDate, format) {
        /** @type {?} */
        const hijriMomentDate = momentHijri(hijriDate, format);
        // Parse a Hijri date based on format.
        /** @type {?} */
        const day = hijriMomentDate.iDate();
        /** @type {?} */
        const month = +hijriMomentDate.iMonth() + 1;
        /** @type {?} */
        const year = hijriMomentDate.iYear();
        /** @type {?} */
        const ngDate = new NgbDate(+year, month, +day);
        return ngDate;
    }
    /**
     * @param {?} gregorianDate
     * @param {?} format
     * @return {?}
     */
    ToGregorianDateStruct(gregorianDate, format) {
        /** @type {?} */
        const momentDate = moment(gregorianDate, format);
        // Parse a Gregorian date based on format.
        /** @type {?} */
        const day = momentDate.date();
        /** @type {?} */
        const month = +momentDate.month() + 1;
        /** @type {?} */
        const year = momentDate.year();
        /** @type {?} */
        const ngDate = new NgbDate(+year, +month, +day);
        return ngDate;
    }
    /**
     * @param {?} date
     * @return {?}
     */
    ToHijri(date) {
        if (!date) {
            return null;
        }
        /** @type {?} */
        const dateStr = this.ToString(date);
        /** @type {?} */
        const momentDate = momentHijri(dateStr, 'D/M/YYYY');
        /** @type {?} */
        const day = momentDate.iDate();
        /** @type {?} */
        const month = +momentDate.iMonth() + 1;
        /** @type {?} */
        const year = momentDate.iYear();
        /** @type {?} */
        const ngDate = new NgbDate(+year, month, +day);
        return ngDate;
    }
    /**
     * @param {?} date
     * @return {?}
     */
    ToGregorian(date) {
        if (!date) {
            return null;
        }
        /** @type {?} */
        const dateStr = this.ToString(date);
        /** @type {?} */
        const momentDate = momentHijri(dateStr, 'iD/iM/iYYYY');
        /** @type {?} */
        const day = momentDate.locale('en').format('D');
        /** @type {?} */
        const month = momentDate.locale('en').format('M');
        /** @type {?} */
        const year = momentDate.locale('en').format('Y');
        /** @type {?} */
        const ngDate = new NgbDate(+year, +month, +day);
        return ngDate;
    }
    /**
     * @return {?}
     */
    GetTodayHijri() {
        /** @type {?} */
        const todayHijri = momentHijri().locale('en').format('iYYYY/iM/iD');
        return this.ToHijriDateStruct(todayHijri, 'iYYYY/iM/iD');
    }
    /**
     * @return {?}
     */
    GetTodayGregorian() {
        /** @type {?} */
        const todayGregorian = moment().locale('en').format('YYYY/M/D');
        return this.ToGregorianDateStruct(todayGregorian, 'YYYY/M/D');
    }
}
DateFormatterService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
DateFormatterService.ctorParameters = () => [
    { type: NgbDateParserFormatter }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-hijri-gregorian-datepicker.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxHijriGregorianDatepickerService {
    constructor() { }
}
NgxHijriGregorianDatepickerService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
NgxHijriGregorianDatepickerService.ctorParameters = () => [];
/** @nocollapse */ NgxHijriGregorianDatepickerService.ngInjectableDef = defineInjectable({ factory: function NgxHijriGregorianDatepickerService_Factory() { return new NgxHijriGregorianDatepickerService(); }, token: NgxHijriGregorianDatepickerService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-hijri-gregorian-datepicker.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxHijriGregorianDatepickerComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
NgxHijriGregorianDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ngx-hijri-gregorian-datepicker',
                template: `
    <p>
      ngx-hijri-gregorian-datepicker works!
    </p>
  `
            }] }
];
/** @nocollapse */
NgxHijriGregorianDatepickerComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/hijri-gregorian-datepicker/hijri-gregorian-datepicker.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$1 = momentjs;
/** @type {?} */
const momentHijri$1 = moment_;
class HijriGregorianDatepickerComponent {
    /**
     * @param {?} dateFormatterService
     */
    constructor(dateFormatterService) {
        this.dateFormatterService = dateFormatterService;
        this.selectedDateChange = new EventEmitter();
        this.readonly = false;
        this.isRequired = false;
        this.disabled = false;
    }
    /**
     * @return {?}
     */
    get DateType() {
        return DateType;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.selectedDateType) {
            this.selectedDateType = DateType.Hijri;
        }
    }
    /**
     * @return {?}
     */
    getSelectedDate() {
        /** @type {?} */
        let formattedDate = this.dateFormatterService.ToString(this.selectedDate);
        if (this.selectedDateType == DateType.Hijri) {
            return momentHijri$1(formattedDate, 'iD/iM/iYYYY').locale('en').format();
        }
        if (this.selectedDateType == DateType.Gregorian) {
            return moment$1(formattedDate, 'D/M/YYYY').locale('en').format();
        }
    }
    /**
     * @return {?}
     */
    dateSelected() {
        this.selectedDateChange.emit(this.selectedDate);
    }
    /**
     * @return {?}
     */
    hijriClick() {
        if (this.selectedDateType == DateType.Hijri) {
            return;
        }
        this.selectedDateType = DateType.Hijri;
        //to hijri
        this.selectedDate = this.dateFormatterService.ToHijri(this.selectedDate);
        this.selectedDateChange.emit(this.selectedDate);
    }
    /**
     * @return {?}
     */
    gregClick() {
        if (this.selectedDateType == DateType.Gregorian) {
            return;
        }
        this.selectedDateType = DateType.Gregorian;
        //to Gregorian
        this.selectedDate = this.dateFormatterService.ToGregorian(this.selectedDate);
        this.selectedDateChange.emit(this.selectedDate);
    }
}
HijriGregorianDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'hijri-gregorian-datepicker',
                template: "\n    <div class=\"form-group\">\n      <label class=\"requiredInput\" for=\"input-birth-Date\">{{ label }} </label>\n\n      <div class=\"input-group\">\n\n          <input  class=\"form-control\"\n                  placeholder=\"d/M/yyyy\"\n                  [name]=\"label\"\n                  *ngIf=\"selectedDateType == DateType.Gregorian\"\n                  [(ngModel)]=\"selectedDate\"\n                  ngbDatepicker (click)=\"d.toggle()\"\n                  (dateSelect)=\"dateSelected()\"\n                  autocomplete=\"off\"\n                  #d=\"ngbDatepicker\"\n                  [readonly]=\"readonly\"\n                  [minDate]=\"minGreg\"\n                  [maxDate]=\"maxGreg\"\n                  [required]=\"isRequired\"\n                  [disabled]=\"disabled\">\n\n\n          <hijri-date-picker *ngIf=\"selectedDateType == DateType.Hijri\"\n                             [(selectedDate)]=\"selectedDate\"\n                             (selectedDateChange)=\"dateSelected()\"\n                             [readonly]=\"readonly\"\n                             [min]=\"minHijri\" [max]=\"maxHijri\"\n                             style=\"flex: 1 1 auto;\"\n                             [name]=\"label\"\n                             [isRequired]=\"isRequired\"\n                             [disabled]=\"disabled\">\n          </hijri-date-picker>\n\n          <div class=\"input-group-append\">\n                  <button class=\"btn btn-sm {{selectedDateType == DateType.Hijri ? 'btn-info focus active' :  'btn-outline-info'}}\" (click)=\"hijriClick()\"  [disabled]=\"disabled\" type=\"button\">\n                     {{hijriLabel ? hijriLabel : 'Hijri' }}\n                  </button>\n                  <button class=\"btn btn-sm {{selectedDateType == DateType.Gregorian ? 'btn-info focus active' :  'btn-outline-info'}}\" (click)=\"gregClick()\" [disabled]=\"disabled\" type=\"button\">\n                      {{GregLabel ? GregLabel : 'Gregorian' }}\n                  </button>\n           </div>\n\n      </div>\n  </div>\n"
            }] }
];
/** @nocollapse */
HijriGregorianDatepickerComponent.ctorParameters = () => [
    { type: DateFormatterService }
];
HijriGregorianDatepickerComponent.propDecorators = {
    selectedDateType: [{ type: Input }],
    selectedDate: [{ type: Input }],
    selectedDateChange: [{ type: Output }],
    label: [{ type: Input }],
    readonly: [{ type: Input }],
    isRequired: [{ type: Input }],
    disabled: [{ type: Input }],
    minHijri: [{ type: Input }],
    maxHijri: [{ type: Input }],
    minGreg: [{ type: Input }],
    maxGreg: [{ type: Input }],
    hijriLabel: [{ type: Input }],
    GregLabel: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/hijri-gregorian-datepicker/IslamicI18n.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const WEEKDAYS = ['أحد', 'إثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'];
/** @type {?} */
const MONTHS = ['محرم', 'صفر', 'ربيع الأول', 'ربيع الآخر', 'جمادى الأولى', 'جمادى الآخرة', 'رجب', 'شعبان', 'رمضان', 'شوال',
    'ذو القعدة', 'ذو الحجة'];
class IslamicI18n extends NgbDatepickerI18n {
    /**
     * @param {?} weekday
     * @return {?}
     */
    getWeekdayShortName(weekday) {
        return WEEKDAYS[weekday - 1];
    }
    /**
     * @param {?} month
     * @return {?}
     */
    getMonthShortName(month) {
        return MONTHS[month - 1];
    }
    /**
     * @param {?} month
     * @return {?}
     */
    getMonthFullName(month) {
        return MONTHS[month - 1];
    }
    /**
     * @param {?} date
     * @return {?}
     */
    getDayAriaLabel(date) {
        return `${date.day}-${date.month}-${date.year}`;
    }
}
IslamicI18n.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/hijri-gregorian-datepicker/hijri-datepicker/hijri-datepicker.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HijriDatepickerComponent {
    constructor() {
        this.selectedDateChange = new EventEmitter();
        this.readonly = false;
        this.isRequired = false;
        this.disabled = false;
    }
    /**
     * @return {?}
     */
    changeDate() {
        this.selectedDateChange.emit(this.selectedDate);
    }
    /**
     * @return {?}
     */
    onBlur() {
        if (!this.selectedDate) {
            this.selectedDateChange.emit(null);
        }
    }
}
HijriDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'hijri-date-picker',
                template: "<input\n    class=\"form-control hijriInput\"\n    [(ngModel)]=\"selectedDate\"\n    placeholder=\"d/M/yyyy\"\n    ngbDatepicker\n    (click)=\"d.toggle()\"\n    (dateSelect)=\"changeDate()\"\n    #d=\"ngbDatepicker\"\n    [readonly]=\"readonly\"\n    [minDate]=\"min\"\n    [maxDate]=\"max\"\n    [required]=\"isRequired\"\n    [name]=\"name\"\n    (blur)=\"onBlur()\"\n    [disabled]=\"disabled\" />\n",
                providers: [
                    { provide: NgbCalendar, useClass: NgbCalendarIslamicUmalqura },
                    { provide: NgbDatepickerI18n, useClass: IslamicI18n }
                ],
                encapsulation: ViewEncapsulation.None,
                styles: [".hijriInput{border-top-left-radius:0;border-bottom-left-radius:0}.ngb-dp-weekday{width:2.1rem!important}"]
            }] }
];
/** @nocollapse */
HijriDatepickerComponent.ctorParameters = () => [];
HijriDatepickerComponent.propDecorators = {
    selectedDate: [{ type: Input }],
    selectedDateChange: [{ type: Output }],
    readonly: [{ type: Input }],
    isRequired: [{ type: Input }],
    disabled: [{ type: Input }],
    min: [{ type: Input }],
    max: [{ type: Input }],
    name: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/hijri-gregorian-datepicker/CustomNgbDateParserFormatter.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CustomNgbDateParserFormatter extends NgbDateParserFormatter {
    /**
     * @param {?} dateFormatString
     */
    constructor(dateFormatString) {
        super();
        this.dateFormatString = dateFormatString;
        this.datePipe = new DatePipe('en-US');
    }
    /**
     * @param {?} date
     * @return {?}
     */
    format(date) {
        if (date === null) {
            return '';
        }
        try {
            return this.datePipe.transform(new Date(date.year, date.month - 1, date.day), this.dateFormatString);
        }
        catch (e) {
            return '';
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    parse(value) {
        /** @type {?} */
        let returnVal;
        if (!value) {
            returnVal = null;
        }
        else {
            try {
                /** @type {?} */
                let dateParts = this.datePipe.transform(value, 'M-d-y').split('-');
                returnVal = { year: parseInt(dateParts[2]), month: parseInt(dateParts[0]), day: parseInt(dateParts[1]) };
            }
            catch (e) {
                returnVal = null;
            }
        }
        return returnVal;
    }
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-hijri-gregorian-datepicker.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxHijriGregorianDatepickerModule {
}
NgxHijriGregorianDatepickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NgxHijriGregorianDatepickerComponent,
                    HijriGregorianDatepickerComponent,
                    HijriDatepickerComponent
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    NgbModule
                ],
                providers: [
                    {
                        provide: NgbDateParserFormatter, /**
                         * @return {?}
                         */
                        useFactory() {
                            return new CustomNgbDateParserFormatter('d/M/yyyy');
                        }
                    },
                    DateFormatterService
                ],
                exports: [HijriGregorianDatepickerComponent, NgxHijriGregorianDatepickerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-hijri-gregorian-datepicker.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { DateType, DateFormatterService, NgxHijriGregorianDatepickerService, NgxHijriGregorianDatepickerComponent, HijriGregorianDatepickerComponent, NgxHijriGregorianDatepickerModule, IslamicI18n as ɵb, HijriDatepickerComponent as ɵa };

//# sourceMappingURL=ngx-hijri-gregorian-datepicker.js.map